{{'{%- extends config.BASE_TEMPLATE %}'}}

{% raw %}
{%- block page_body %}
<div class="container">
  {# TODO: Example homepage, please remove if you do not need it. #}
  {{_('Welcome to %(module_name)s', module_name=module_name)}}
</div>
{%- endblock %}
{% endraw %}
