# -*- coding: utf-8 -*-

"""Version information for {{ cookiecutter.site_name }}.

This file is imported by ``{{ cookiecutter.package_name }}.__init__``,
and parsed by ``setup.py``.
"""

__version__ = "0.1.0.dev0"
